@@ -131,12 +131,13 @@ int main(int argc, char *argv[])
 	Config.SpuIrq = 0;
 	Config.VSyncWA = 0;
 	displayFrameInfo = 0;
-
+bool fullscreen=false;
 	for (i=1; i<argc; i++) {
 		if (!strcmp(argv[i], "-runcd")) runcd = 1;
 		else if (!strcmp(argv[i], "-psxout")) Config.PsxOut = 1;
 		else if (!strcmp(argv[i], "-load")) loadst = argv[++i];
 		else if (!strcmp(argv[i], "-nosound")) iSoundMuted = 1;
+		else if (!strcmp(argv[i], "-fullscreen")) fullscreen = 1;
 		else if (!strcmp(argv[i], "-showfps")) displayFrameInfo = 1;
 #if defined(ENABLE_GPU_PRIM_STATS) || defined(ENABLE_GPU_PROFILLER)
 		else if (!strcmp(argv[i], "-gpustats")) displayGpuStats = 1;
@@ -198,7 +199,7 @@ int main(int argc, char *argv[])
 	gp2x_init(1000, 16, 11025, 16, 1, 60, 1);
 
 #ifdef MAEMO_CHANGES
-	hildon_init (&argc, &argv,file,loadst);
+	hildon_init (&argc, &argv,file,loadst,fullscreen);
 #endif
 
 	if (SysInit() == -1) return 1;
@@ -249,7 +250,9 @@ int main(int argc, char *argv[])
 		"Frame Skip               %d/%d\n"
 		"Cycle Multiplier         %d\n"
 		"Abe's Oddysee Fix        %s\n"
-		"Sound                    %s\n",
+		"Sound                    %s\n"
+		"Fullscreen               %s\n",
+		
 		file,
 		(displayFrameInfo == false ? "OFF" : "ON"),
 #if defined(ENABLE_GPU_PRIM_STATS) || defined(ENABLE_GPU_PROFILLER)
@@ -262,7 +265,8 @@ int main(int argc, char *argv[])
 		skipCount, skipRate,
 		PsxCycleMult,
 		(enableAbbeyHack == false ? "OFF" : "ON"),
-		(iSoundMuted == 0 ? "ON" : "OFF")
+		(iSoundMuted == 0 ? "ON" : "OFF"),
+		(fullscreen == 0 ? "ON" : "OFF")
 	);
 #endif
 
@@ -292,14 +296,18 @@ int SysInit() {
 	setvbuf(gteLog, NULL, _IONBF, 0);
 #endif
 
-#ifdef EMU_LOG
-#ifndef LOG_STDOUT
-	emuLog = fopen("emuLog.txt","wb");
-#else
+
+if (Config.PsxOut)
+{
 	emuLog = stdout;
-#endif
-	setvbuf(emuLog, NULL, _IONBF, 0);
-#endif
+}
+else
+{
+	emuLog = fopen("emuLog.txt","wb");
+}
+
+setvbuf(emuLog, NULL, _IONBF, 0);
+
 
 	psxInit();
 	//LoadPlugins();
@@ -334,11 +342,8 @@ void SysPrintf(char *fmt, ...) {
 	va_end(list);
 
 	if (Config.PsxOut) printf ("%s\n", msg);
-#ifdef EMU_LOG
-#ifndef LOG_STDOUT
+if (Config.PsxOut)
 	fprintf(emuLog, "%s\n", msg);
-#endif
-#endif
 }
 
 void *SysLoadLibrary(char *lib) {
