@@ -130,7 +130,7 @@ window_key_proxy (GtkWidget *widget,
 }
 
 
-void hildon_init(int *argc, char ***argv,char *fl,char* lst)
+void hildon_init(int *argc, char ***argv,char *fl,char* lst,bool fullscreen)
 {
 	file=fl;
 	cfile="/opt/usr/psx4m/savestate";
@@ -148,7 +148,7 @@ void hildon_init(int *argc, char ***argv,char *fl,char* lst)
 			fscanf(pFile, "%i",&ch);
 			keymap[ch]=i;
 			}catch(int e){
-			keymap[i]=0;
+			keymap[i]=164;
 			}
 		}
 		fclose(pFile);
@@ -168,7 +168,12 @@ void hildon_init(int *argc, char ***argv,char *fl,char* lst)
 				GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK);
 
 	actor = HILDON_ANIMATION_ACTOR (hildon_animation_actor_new());
+	if (!fullscreen){
 	hildon_animation_actor_set_position (actor, (X_RES - D_WIDTH)/2, (Y_RES - D_HEIGHT)/2 );
+	}else{
+	hildon_animation_actor_set_position (actor, 0, 0 );
+	gp2x_change_res(800,480);
+	}
 	hildon_animation_actor_set_parent (actor, GTK_WINDOW (window));
 
 	drawing = gtk_image_new ();
